import type { Dayjs } from 'dayjs'
import type { TimeBarInstance, TimeBarProps } from './types'
import { getBooleanOrDefault } from '../../utils'
import { isProdMode } from '/@/utils/env'

export function formatTime(time: Dayjs, format = 'YYYY-MM-DD HH:mm:ss') {
    return time?.format(format) ?? ''
}

export function getFormatByType(type: number) {
    switch (type) {
        case 1:
            return 'YYYY'
        case 2:
            return 'YYYY-MM'
        case 3:
            return 'YYYY-MM-DD'
        case 4:
            return 'YYYY-MM-DD HH:00'
        case 5:
            return 'YYYY-MM-DD HH:mm'
        case 6:
            return 'YYYY-MM-DD HH:mm:ss'
        default:
            return 'YYYY-MM-DD HH:mm:ss'
    }
}

/**
 * 顶部时间栏组件响应式 Hook
 * @param props 组件参数
 * @returns 组件响应式数据
 */
export function useTimeBarWidget<T extends TimeBarInstance>(props: TimeBarProps): [(instance: T) => void, T] {
    const instanceRef = ref<Nullable<T>>(null)

    function register(instance: T) {
        if (isProdMode()) {
            if (instance === unref(instanceRef)) {
                return
            }

            onUnmounted(() => {
                instanceRef.value = null
            })
        }

        instanceRef.value = instance
        props && instance?.setProps(props)
    }

    function getInstance(): T {
        const instance = unref(instanceRef)
        if (!instance) {
            console.warn('时间栏小部件还未加载完成')
        }
        return instance as T
    }

    return [
        register,
        {
            setProps: (props: TimeBarProps) => {
                getInstance()?.setProps(props)
            },
            toggleShow: (show?: boolean) => {
                getInstance()?.toggleShow(getBooleanOrDefault(show))
            },
        } as T,
    ]
}
