import type { Dayjs } from 'dayjs'

type FirstUIDatePickerType = 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8

export interface TimeBarChangeEvent {
    value: Dayjs[]
    option?: {
        text?: string
        value?: string
    }
}

export interface TimeBarLabel {
    text?: string
    breforeIcon?: boolean
    afterIcon?: boolean
    options?: {
        text?: string
        value?: string
        checked?: boolean
        format?: string
        /**
         * 对应 first-ui datePicker 组件 type 参数
         */
        timeType?: FirstUIDatePickerType
    }[]
    onClick?: () => void
    onChange?: (e: TimeBarChangeEvent) => void
}

export interface TimeBarTime {
    type: 'single' | 'range'
    /**
     * 对应 first-ui datePicker 组件 type 参数
     */
    timeType: FirstUIDatePickerType
    format?: string
    value?: Dayjs[]
    onChange?: (e: TimeBarChangeEvent) => void
}

export interface TimeBarButton {
    icon?: string
    label: string
    onClick?: (e: { index: number; label: string }, time: string | { start?: string; end?: string }) => void
}

export interface TimeBarProps {
    // 是否显示
    show?: boolean
    // 是否只读
    readonly?: boolean
    // 对齐方式
    align?: 'left' | 'center' | 'right'
    // 标题
    label?: TimeBarLabel
    // 时间
    time: TimeBarTime
    // 扩展按钮
    buttons?: TimeBarButton[]
}

export interface TimeBarInstance {
    setProps: (props: TimeBarProps) => void
    toggleShow: (show?: boolean) => void
}
